@@ -150,7 +150,8 @@ class Document(GObject.Object, Gedit.ViewActivatable, Signals):
                 else:
                         # Do the fancy completion dialog
                         self.provider.set_proposals(snippets)
-                        self.view.show_completion((self,))
+                        cm = self.view.get_completion()
+                        cm.show([self.provider], cm.create_context(None))
 
                 return True
 
@@ -660,7 +661,7 @@ class Document(GObject.Object, Gedit.ViewActivatable, Signals):
                                 self.provider.set_proposals(snippets)
                                 cm = self.view.get_completion()
 
-                                cm.show([self.provider], cm.create_context())
+                                cm.show([self.provider], cm.create_context(None))
                                 return True
 
                 return False
